pub enum AggchainData {
LegacyEcdsa {
signer: Address,
signature: Signature,
},
MultisigOnly(MultiSignature),
MultisigAndAggchainProof {
multisig: MultiSignature,
aggchain_proof: AggchainProof,
},
}Expand description
Chain proof which include either multisig, aggchain proof, or both. Explicit enum which forbid the case where we have none of them.
Variants
LegacyEcdsa
Legacy signature with migration logic
Fields

signer: AddressSigner committing to the state transition.

signature: SignatureSignature committing to the state transition.
MultisigOnly(MultiSignature)
Multisig only
MultisigAndAggchainProof
Multisig and an aggchain proof
Implementations
Sourceimpl AggchainData
impl AggchainData
Sourcepub fn aggchain_hash(&self) -> Digest
pub fn aggchain_hash(&self) -> Digest
Returns the aggchain hash
pub fn verify( &self, constrained_values: ConstrainedValues, ) -> Result<PessimisticRootCommitmentVersion, ProofError>
Sourceimpl AggchainData
impl AggchainData
Sourcepub fn legacy_ecdsa(
signer: &Address,
signature: &Signature,
constrained_values: ConstrainedValues,
) -> Result<PessimisticRootCommitmentVersion, ProofError>
pub fn legacy_ecdsa( signer: &Address, signature: &Signature, constrained_values: ConstrainedValues, ) -> Result<PessimisticRootCommitmentVersion, ProofError>
Returns the target PP root version based on the signature.