pub struct MultiBatchHeader {
pub origin_network: NetworkId,
pub height: u64,
pub prev_pessimistic_root: Digest,
pub bridge_exits: Vec<BridgeExit>,
pub imported_bridge_exits: Vec<(ImportedBridgeExit, NullifierPath)>,
pub l1_info_root: Digest,
pub balances_proofs: BTreeMap<TokenInfo, (U256, LocalBalancePath)>,
pub aggchain_data: AggchainData,
pub certificate_id: Digest,
}Expand description
Represents the chain state transition for the pessimistic proof.
Fields
origin_network: NetworkIdNetwork that emitted this MultiBatchHeader.
height: u64Current certificate height of the L2 chain.
prev_pessimistic_root: DigestPrevious pessimistic root.
bridge_exits: Vec<BridgeExit>List of bridge exits created in this batch.
imported_bridge_exits: Vec<(ImportedBridgeExit, NullifierPath)>List of imported bridge exits claimed in this batch.
l1_info_root: DigestL1 info root used to import bridge exits.
balances_proofs: BTreeMap<TokenInfo, (U256, LocalBalancePath)>Token balances of the origin network before processing bridge events, with Merkle proofs of these balances in the local balance tree.
aggchain_data: AggchainDataAggchain data which include either multisig, aggchain proof, or both.
certificate_id: DigestCertificate id used as nonce to compute the commitment.
Implementations
Sourceimpl MultiBatchHeader
impl MultiBatchHeader
Sourcepub fn commit_imported_bridge_exits(&self) -> ImportedBridgeExitCommitmentValues
pub fn commit_imported_bridge_exits(&self) -> ImportedBridgeExitCommitmentValues
Returns the commitment on the imported bridge exits.