ProofError

Enum ProofError 

pub enum ProofError {
Show 26 variants InvalidPreviousLocalExitRoot { declared: Digest, computed: Digest, }, InvalidPreviousBalanceRoot { declared: Digest, computed: Digest, }, InvalidPreviousNullifierRoot { declared: Digest, computed: Digest, }, InvalidNewLocalExitRoot { declared: Digest, computed: Digest, }, InvalidNewBalanceRoot { declared: Digest, computed: Digest, }, InvalidNewNullifierRoot { declared: Digest, computed: Digest, }, InvalidImportedBridgeExit { source: Error, global_index: GlobalIndex, }, InvalidImportedExitsRoot { declared: Digest, computed: Digest, }, MismatchImportedExitsRoot, InvalidNullifierPath, InvalidBalancePath, BalanceOverflowInBridgeExit, BalanceUnderflowInBridgeExit, CannotExitToSameNetwork, InvalidMessageOriginNetwork, InvalidL1TokenInfo(TokenInfo), MissingTokenBalanceProof(TokenInfo), DuplicateTokenBalanceProof(TokenInfo), InvalidSignature, InvalidSigner { declared: Address, recovered: Address, }, InvalidLocalExitTreeOperation(LocalExitTreeError), Unknown(String), InvalidPreviousPessimisticRoot { declared: Digest, computed_v2: Digest, computed_v3: Digest, }, InconsistentSignedPayload, HeightOverflow, InvalidMultisig(MultisigError),
}
Represents all errors that can occur while generating the proof.

Several commitments are declared either by the chains (e.g., the local exit root) or by the agglayer (e.g., the balance and nullifier root), and are later re-computed by the prover to ensure that they match the witness data. Consequently, several errors highlight a mismatch between what is declared as witness and what is computed by the prover.

Variants



InvalidPreviousLocalExitRoot

Fields

declared: Digest
computed: Digest


InvalidPreviousBalanceRoot

Fields

declared: Digest
computed: Digest


InvalidPreviousNullifierRoot

Fields

declared: Digest
computed: Digest


InvalidNewLocalExitRoot

Fields

declared: Digest
computed: Digest


InvalidNewBalanceRoot

Fields

declared: Digest
computed: Digest


InvalidNewNullifierRoot

Fields

declared: Digest
computed: Digest


InvalidImportedBridgeExit

The provided imported bridge exit is invalid.

Fields

source: Error
global_index: GlobalIndex


InvalidImportedExitsRoot

The commitment to the list of imported bridge exits is invalid.

Fields

declared: Digest
computed: Digest


MismatchImportedExitsRoot



InvalidNullifierPath

The provided nullifier path is invalid.



InvalidBalancePath

The provided balance path is invalid.



BalanceOverflowInBridgeExit

The imported bridge exit led to balance overflow.



BalanceUnderflowInBridgeExit

The bridge exit led to balance underflow.



CannotExitToSameNetwork

The provided bridge exit goes to the sender’s own network which is not permitted.



InvalidMessageOriginNetwork

The provided bridge exit message is invalid.



InvalidL1TokenInfo(TokenInfo)

The token address is zero if and only if it refers to the L1 native eth.



MissingTokenBalanceProof(TokenInfo)

The provided token is missing a balance proof.



DuplicateTokenBalanceProof(TokenInfo)

The provided token comes with multiple balance proofs.



InvalidSignature

The signature on the state transition is invalid.



InvalidSigner

The signer recovered from the signature differs from the one declared as witness.

Fields

declared: Address
recovered: Address


InvalidLocalExitTreeOperation(LocalExitTreeError)

The operation cannot be applied on the local exit tree.



Unknown(String)

Unknown error.



InvalidPreviousPessimisticRoot

The previous pessimistic root is not re-computable.

Fields

declared: Digest
computed_v2: Digest
computed_v3: Digest


InconsistentSignedPayload

The signature is on a payload that is with an inconsistent version.



HeightOverflow

Height overflow.



InvalidMultisig(MultisigError)

Invalid multisig